import pathlib

from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name='ose-workbench-platform',
    description='Common platform for developing Open Source Ecology (OSE) workbenches.',
    long_description_content_type="text/markdown",
    url='https://github.com/gbroques/ose-workbench-platform',
    author='G Roques',
    version='0.1.0a1',
    packages=['osewb'],
    entry_points={
        'console_scripts': [
            'osewb = osewb.osewb:main'
        ]
    },
)



import argparse


def main():
    sub_command = _parse_sub_command()
    print("Sub command: {}".format(sub_command))


def _parse_sub_command():
    sub_commands = {
        'init': 'Initialize new workbench',
        'test': 'Run all tests in workbench'
    }
    usage = 'osewb <command> [<args>]\n'
    for command, description in sub_commands.items():
        usage += '    {} - {}\n'.format(command, description)
    parser = argparse.ArgumentParser(
        description='A collection of OSE workbench commands.', usage=usage)
    parser.add_argument('command',
                        metavar='<command>',
                        type=str,
                        nargs=1,
                        help=', '.join((sub_commands.keys())),
                        choices=sub_commands.keys())
    args = parser.parse_args()
    return vars(args)['command'][0]


if __name__ == "__main__":
    main()
